@@ -3,10 +3,10 @@
  *
  * Ref: FIPS PUB 198 The Keyed-Hash Message Authentication Code
  *
- * Copyright (C) 2003-2005 Mark Shelor, All Rights Reserved
+ * Copyright (C) 2003-2006 Mark Shelor, All Rights Reserved
  *
- * Version: 5.31
- * Mon Sep  5 00:52:42 MST 2005
+ * Version: 5.34
+ * Thu Feb  2 18:55:40 MST 2006
  *
  */
 
@@ -22,7 +22,7 @@ int alg;
 unsigned char *key;
 unsigned int keylen;
 {
-	int i;
+	unsigned int i;
 	HMAC *h;
 
 	SHA_newz(0, h, 1, HMAC);
